local L = AceLibrary("AceLocale-2.2"):new("ItsG15Binder")

local cb = '|cff6666ff'
local cv = '|cff9999ff'
local cg = '|cff00ff00'
local cr = '|r'
local ph = '•'

local M = cb..'M'..cr
local G = cb..'G'..cr
local PH = cv..ph..cr

local function j(...)
    local t = {}
    for i=1,select('#',...) do
        t[i] = tostring(select(i,...))
    end
    return table.concat(t,'')
end

L:RegisterTranslations("enUS", function() return {

    BIND_NAME = 'Binding',
    BIND_DESC = 'Set up bindings between physical G keys and in-game action buttons.',
    CLEAR_NAME = 'Clear',
    CLEAR_DESC = 'Clears all G key bindings.',
    CLEAR_CONFIRM = 'Are you sure you want to clear all G key bindings?  This operation CANNOT be reversed.',

    KEYS_NAME = 'Keys',
    KEYS_DESC = 'Specify which keys to use in the bindings.  Please note that you need two distinct keys which DO NOT use any modifiers.',
    KEY1_NAME = 'Key 1',
    KEY1_DESC = 'First key used for binding.  Unless you have customised your G15 Keyboard profile, this should be \'F6\'.',
    KEY1_USAGE = '<KEY>',
    KEY2_NAME = 'Key 2',
    KEY2_DESC = 'First key used for binding.  Unless you have customised your G15 Keyboard profile, this should be \'F7\'.',
    KEY2_USAGE = '<KEY>',

    BINDMODE_NAME = 'Binding mode',
    BINDMODE_DESC = 'Set the binding mode.',
    BINDMODE_DESC_GUI = [[Set the binding mode.

|cffffffff•|r |cff00ff00Off|r - disable binding mode.
|cffffffff•|r |cff00ff00Single|r - bind single G keys to specific action buttons.
|cffffffff•|r |cff00ff00Range|r - bind ranges of G keys to ranges of action buttons.]],

    BINDMODE_USAGE = '{off || single || range}',
    BINDMODE_VALID = {
        off = '|cff00ff00off|r - disable binding',
        single = '|cff00ff00single|r - bind single G keys to specific action buttons',
        range = '|cff00ff00range|r - bind ranges of G keys to ranges of action buttons',
    },

    MODE_NAME = 'Mode display',
    MODE_DESC = 'Control how the current key mode is displayed.',
    BORDER_NAME = 'Border display',
    BORDER_DESC = 'Displays a border around the active group of G keys.',
    PADDING_NAME = 'Padding',
    PADDING_DESC = 'Amount of space between the border and the buttons it surrounds.',
    COLOR_NAME = 'Border color',
    COLOR_DESC = 'Color of the border.',
    BG_COLOR_NAME = 'Background color',
    BG_COLOR_DESC = 'Color of the background.',
    PAGE_NAME = 'Actionbar paging',
    PAGE_DESC = 'Causes the actionbar page number to change depending on which mode is active.  If you intend to use all the G keys on a single bank of buttons, you must bind all the G keys you wish to use across all three modes to the same buttons.',
    MODE1_NAME = 'Mode 1',
    MODE1_DESC = 'The action bar page which Mode 1 activates.',
    MODE2_NAME = 'Mode 2',
    MODE2_DESC = 'The action bar page which Mode 2 activates.',
    MODE3_NAME = 'Mode 3',
    MODE3_DESC = 'The action bar page which Mode 3 activates.',

    ENABLED_NAME = 'Enabled?',
    ENABLED_DESC = 'Do you want to enable this?',

    BORDER_STYLE_NAME = 'Border style',
    BORDER_STYLE_DESC = 'Set the style for the border',
    BACK_STYLE_NAME = 'Background style',
    BACK_STYLE_DESC = 'Set the style for the background',
    BACK_BLEND_NAME = 'Background blending',
    BACK_BLEND_DESC = 'Set how the background should blend with things behind it',

    WATERFALL_TITLE = "Its' G15 Binder",
    CONFIG_NAME = 'Configure',
    CONFIG_DESC = 'Open a configuration dialog.',

    ERR_GENERAL = '|cffff0000Error|r:',
    ERR_NOT_BUTTON = '|cffff0000Error|r: Frame %s does not appear to be a button.',
    BINDING_RANGE_START = 'Binding range starting with |cff8888ff%s|r and |cff88ff88%s|r...',
    BINDING_RANGE = 'Binding |cff8888ffM%sG%s|r-|cff8888ffM%sG%s|r to action buttons |cff88ff88%s|r-|cff88ff88%s|r...',
    ERR_DIFF_NUM = '|cffff0000Error|r: different number of G keys and action buttons; %s G keys to %s action buttons.',
    DONE = 'Done.',
    BINDING_KEY_REPL = 'Binding |cff8888ff%s|r to |cff88ff88%s|r (replacing |cffff8888%s|r.)',
    BINDING_KEY = 'Binding |cff8888ff%s|r to |cff88ff88%s|r.',
    
    SINGLE_BINDING_ENABLED =
        '|c88ff88ffSingle key|r binding mode has been enabled.  ' ..
        'Place your mouse cursor over the action button you wish to '..
        'bind to and press the corresponding G key.  You will get a '..
        'confirmation message in your chat log.  '..
        'Don\'t forget to turn off binding when you are done!',

    RANGE_BINDING_ENABLED =
        '|c88ff88ffRange|r binding has been enabled.  '..
        'Place your mouse cursor over the first action button in the range '..
        'you wish to bind and press the corresponding G key.  '..
        'You will get a confirmation message in your chat log.  '..
        'Then, place your mouse cursor over the last action button in the '..
        'range you wish to bind and press the corresponding G key.  '..
        'You will get a message for each key in the range which will be '..
        'bound.  Don\'t forget to turn off binding when you are done!',

    BINDINGS_CLEARED = 'All G key bindings have been cleared.',
    BINDING_DISABLED = 'Binding mode has been disabled.',

    DISPLAY_NAME = 'Display',
    DISPLAY_DESC = 'Control display options',

    OVERLAY_NAME = 'Key overlays',
    OVERLAY_DESC = 'Overlays the name of the key bound to an action button.',

    OVERLAY_FORMAT_NAME = 'Format',
    OVERLAY_FORMAT_DESC = 'Format of the key overlays.',

    OVERLAY_FORMAT_USAGE = '{g || m-g || m-space-g || m-comma-g}',

    --[[
    OVERLAY_FORMAT_VALID = {
        'g', 'm-g', 'm-space-g', 'm-comma-g',
    },
    --]]

    OVERLAY_FORMAT_VALID--[[_DESC]] = {
        ['g'] = j(cg,'g',cr,' - ',G,PH),
        ['m-g'] = j(cg,'m-g',cr,' - ',M,PH,G,PH),
        ['m-space-g'] = j(cg,'m-space-g',cr,' - ',M,PH,' ',G,PH),
        ['m-comma-g'] = j(cg,'m-comma-g',cr,' - ',PH,',',PH),
    },

    OVERLAY_FORMAT = {
        ['g'] = function(m,g) return 'G'..g end,
        ['m-g'] = function(m,g) return 'M'..m..'G'..g end,
        ['m-space-g'] = function(m,g) return 'M'..m..' G'..g end,
        ['m-comma-g'] = function(m,g) return m..','..g end,
    },

    OVERLAY_ANCHOR_NAME = 'Anchor',
    OVERLAY_ANCHOR_DESC = 'Control in which corner of the action button key overlays are anchored.',

    --[[
    OVERLAY_ANCHOR_VALID = {
        'CENTER',
        'TOPLEFT', 'TOP', 'TOPRIGHT',
        'RIGHT', 'BOTTOMRIGHT', 'BOTTOM',
        'BOTTOMLEFT', 'LEFT',
    },
    --]]

    OVERLAY_ANCHOR_VALID--[[_DESC]] = {
        CENTER = j(cg,'CENTER',cr,' - Center'),
        TOPLEFT = j(cg,'TOPLEFT',cr,' - Top left'),
        TOP = j(cg,'TOP',cr,' - Top'),
        TOPRIGHT = j(cg,'TOPRIGHT',cr,' - Top right'),
        RIGHT = j(cg,'RIGHT',cr,' - Right'),
        BOTTOMRIGHT = j(cg,'BOTTOMRIGHT',cr,' - Bottom right'),
        BOTTOM = j(cg,'BOTTOM',cr,' - Bottom'),
        BOTTOMLEFT = j(cg,'BOTTOMLEFT',cr,' - Bottom left'),
        LEFT = j(cg,'LEFT',cr,' - Left'),
    },

    OVERLAY_COLOR_NAME = 'Color',
    OVERLAY_COLOR_DESC = 'Set the color of the overlay text.',

    OVERLAY_SCALE_NAME = 'Scale',
    OVERLAY_SCALE_DESC = 'Set the scale of the overlay text.',

    ARE_YOU_SURE = 'Are you sure?',

    ["ChatCommands"] = {
        "/g15binder", "/g15"
    },

} end )
